@@ -1,6 +1,7 @@
 #include "main.hpp"
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 49)
+#include <algorithm>
 #include <pybind11/stl.h>
 #include <unicode/icudataver.h>
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 49)
@@ -14,9 +15,11 @@ void init_icudataver(py::module &m) {
     ErrorCode error_code;
     u_getDataVersion(info, error_code);
     if (error_code.isFailure()) {
-      throw ICUError(error_code);
+      throw icupy::ICUError(error_code);
     }
-    std::vector<uint8_t> result(info, info + sizeof(info));
+    py::tuple result(U_MAX_VERSION_LENGTH);
+    int n = 0;
+    std::for_each(std::begin(info), std::end(info), [&](auto v) { result[n++] = v; });
     return result;
   });
 
