@@ -10,7 +10,7 @@ if sys.platform.startswith("win"):
 
     path = (  # type: ignore
         Path(os.getenv("ICU_ROOT", "C:/icu")) / "bin64"
-        if sys.maxsize > 2 ** 32
+        if sys.maxsize > 2**32
         else "bin"
     ).resolve()
     if not path.is_dir():
@@ -27,10 +27,4 @@ if sys.platform.startswith("win"):
         )
     del path
 
-from . import icu  # type: ignore
-
-__version__ = icu.VERSION_INFO
-
-# DEPRECATED: ICUException is deprecated. Use ICUError instead.
-# TODO: Remove ICUException in a future release.
-ICUException = icu.ICUError
+from . import icu  # noqa: F401
