@@ -5,6 +5,7 @@
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 63)
 
 #include "usetptr.hpp"
+#include <algorithm>
 #include <memory>
 #include <pybind11/stl.h>
 #include <unicode/uchar.h>
@@ -1409,7 +1410,9 @@ void init_uchar(py::module &m) {
       [](UChar32 c) {
         UVersionInfo info;
         u_charAge(c, info);
-        std::vector<uint8_t> result(info, info + sizeof(info));
+        py::tuple result(U_MAX_VERSION_LENGTH);
+        int n = 0;
+        std::for_each(std::begin(info), std::end(info), [&](auto v) { result[n++] = v; });
         return result;
       },
       py::arg("c"));
@@ -1424,7 +1427,7 @@ void init_uchar(py::module &m) {
         ErrorCode error_code;
         auto result = u_charFromName(name_choice, name, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -1441,7 +1444,7 @@ void init_uchar(py::module &m) {
         error_code.reset();
         u_charName(code, name_choice, result.data(), static_cast<int32_t>(result.size()), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -1466,7 +1469,7 @@ void init_uchar(py::module &m) {
         ErrorCode error_code;
         auto uset = u_getBinaryPropertySet(property, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_ConstUSetPtr>(uset);
       },
@@ -1484,7 +1487,7 @@ void init_uchar(py::module &m) {
         error_code.reset();
         u_getFC_NFKC_Closure(c, result.data(), static_cast<int32_t>(result.size()), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -1497,7 +1500,7 @@ void init_uchar(py::module &m) {
         ErrorCode error_code;
         auto map = u_getIntPropertyMap(property, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_ConstUCPMapPtr>(map);
       },
@@ -1525,7 +1528,9 @@ void init_uchar(py::module &m) {
   m.def("u_get_unicode_version", []() {
     UVersionInfo info;
     u_getUnicodeVersion(info);
-    std::vector<uint8_t> result(info, info + sizeof(info));
+    py::tuple result(U_MAX_VERSION_LENGTH);
+    int n = 0;
+    std::for_each(std::begin(info), std::end(info), [&](auto v) { result[n++] = v; });
     return result;
   });
 
