@@ -86,7 +86,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto p = ucnv_clone(cnv, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UConverterPtr>(p);
       },
@@ -104,7 +104,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_countAliases(alias, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -143,7 +143,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getAlias(alias, n, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -155,13 +155,13 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         const auto count = ucnv_countAliases(alias, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
-        std::vector<const char *> result(count);
+        std::vector<const char *> result(count, nullptr);
         error_code.reset();
         ucnv_getAliases(alias, result.data(), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -175,7 +175,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getCanonicalName(alias, standard, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -187,7 +187,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getCCSID(converter, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -204,7 +204,7 @@ void init_ucnv(py::module &m) {
         error_code.reset();
         ucnv_getDisplayName(converter, display_locale, result.data(), static_cast<int32_t>(result.size()), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -255,7 +255,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getName(converter, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -267,7 +267,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getPlatform(converter, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -279,7 +279,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getStandard(n, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -291,7 +291,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_getStandardName(name, standard, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -305,7 +305,7 @@ void init_ucnv(py::module &m) {
         int8_t len = sizeof(sub_chars);
         ucnv_getSubstChars(converter, sub_chars, &len, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return py::bytes(sub_chars, len);
       },
@@ -359,7 +359,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_getUnicodeSet(cnv, set_fill_in, which_set, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
       },
       py::arg("cnv"), py::arg("set_fill_in"), py::arg("which_set"));
@@ -373,7 +373,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto result = ucnv_isFixedWidth(cnv, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -385,7 +385,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto p = ucnv_open(converter_name, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UConverterPtr>(p);
       },
@@ -395,7 +395,7 @@ void init_ucnv(py::module &m) {
     ErrorCode error_code;
     auto p = ucnv_openAllNames(error_code);
     if (error_code.isFailure()) {
-      throw ICUError(error_code);
+      throw icupy::ICUError(error_code);
     }
     return std::make_unique<_UEnumerationPtr>(p);
   });
@@ -406,7 +406,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto p = ucnv_openCCSID(codepage, platform, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UConverterPtr>(p);
       },
@@ -418,7 +418,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto p = ucnv_openPackage(package_name, converter_name, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UConverterPtr>(p);
       },
@@ -430,7 +430,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         auto p = ucnv_openStandardNames(conv_name, standard, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UEnumerationPtr>(p);
       },
@@ -477,7 +477,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_setFromUCallBack(converter, fp, cp, &old_action, &old_context, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         if (old_action == new_action.callback) {
           // Old Python callback function and callback data
@@ -511,7 +511,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_setFromUCallBack(converter, fp, cp, &old_action, &old_context, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         if (old_action == new_action.callback) {
           // Old Python callback function and callback data
@@ -531,7 +531,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_setSubstChars(converter, sub_chars, len, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
       },
       py::arg("converter"), py::arg("sub_chars"), py::arg("len_"));
@@ -542,7 +542,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_setSubstString(converter, s, length, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
       },
       py::arg("converter"), py::arg("s"), py::arg("length"));
@@ -572,7 +572,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_setToUCallBack(converter, fp, cp, &old_action, &old_context, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         if (old_action == new_action.callback) {
           // Old Python callback function and callback data
@@ -606,7 +606,7 @@ void init_ucnv(py::module &m) {
         ErrorCode error_code;
         ucnv_setToUCallBack(converter, fp, cp, &old_action, &old_context, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         if (old_action == new_action.callback) {
           // Old Python callback function and callback data
