@@ -40,7 +40,7 @@ void init_ucsdet(py::module &m) {
         ErrorCode error_code;
         auto p = ucsdet_detect(ucsd, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         } else if (p == nullptr) {
           return std::nullopt;
         }
@@ -55,11 +55,12 @@ void init_ucsdet(py::module &m) {
         int32_t matches_found;
         auto p = ucsdet_detectAll(ucsd, &matches_found, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
-        std::vector<std::unique_ptr<_ConstUCharsetMatchPtr>> result(matches_found);
+        std::vector<std::unique_ptr<_ConstUCharsetMatchPtr>> result;
+        result.reserve(matches_found);
         for (int32_t n = 0; n < matches_found; ++n, ++p) {
-          result[n] = std::move(std::make_unique<_ConstUCharsetMatchPtr>(*p));
+          result.push_back(std::move(std::make_unique<_ConstUCharsetMatchPtr>(*p)));
         }
         return result;
       },
@@ -76,7 +77,7 @@ void init_ucsdet(py::module &m) {
         ErrorCode error_code;
         auto p = ucsdet_getAllDetectableCharsets(ucsd, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UEnumerationPtr>(p);
       },
@@ -88,7 +89,7 @@ void init_ucsdet(py::module &m) {
         ErrorCode error_code;
         auto result = ucsdet_getConfidence(ucsm, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -100,7 +101,7 @@ void init_ucsdet(py::module &m) {
         ErrorCode error_code;
         auto result = ucsdet_getLanguage(ucsm, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -112,7 +113,7 @@ void init_ucsdet(py::module &m) {
         ErrorCode error_code;
         auto result = ucsdet_getName(ucsm, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -127,7 +128,7 @@ void init_ucsdet(py::module &m) {
         error_code.reset();
         ucsdet_getUChars(ucsm, result.data(), cap, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -141,7 +142,7 @@ void init_ucsdet(py::module &m) {
     ErrorCode error_code;
     auto p = ucsdet_open(error_code);
     if (error_code.isFailure()) {
-      throw ICUError(error_code);
+      throw icupy::ICUError(error_code);
     }
     return std::make_unique<_UCharsetDetectorPtr>(p);
   });
@@ -152,7 +153,7 @@ void init_ucsdet(py::module &m) {
         ErrorCode error_code;
         ucsdet_setDeclaredEncoding(ucsd, encoding, length, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
       },
       py::arg("ucsd"), py::arg("encoding"), py::arg("length") = -1);
@@ -168,7 +169,7 @@ void init_ucsdet(py::module &m) {
         std::memcpy(s, text_in, size);
         ucsdet_setText(ucsd, s, len, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         ucsd.set_source(source);
       },
