@@ -10,42 +10,50 @@
 using namespace icu;
 
 _UTextPtr::_UTextPtr() : p_(nullptr) {}
+
 _UTextPtr::_UTextPtr(UText *p) : p_(p) {}
+
 _UTextPtr::_UTextPtr(UText *p, const std::shared_ptr<void> &source) : p_(p), source_(source) {}
+
 _UTextPtr::~_UTextPtr() {}
+
 UText *_UTextPtr::get() const { return p_; }
 
 const std::shared_ptr<void> &_UTextPtr::get_source() const { return source_; }
 
-_UTextVector::_UTextVector(size_t n) {
-  values_ = std::vector<_UTextPtr>(n);
-  sources_ = std::vector<UnicodeString>(n);
-  ErrorCode error_code;
-  for (size_t i = 0; i < n; ++i) {
-    error_code.reset();
-    values_[i] = utext_openUnicodeString(nullptr, &sources_[i], error_code);
-    if (error_code.isFailure()) {
-      throw ICUError(error_code);
-    }
-  }
-}
+_UTextVector::_UTextVector() {}
 
-_UTextVector::_UTextVector(const _UnicodeStringList &iterable) {
+_UTextVector::_UTextVector(const std::list<std::reference_wrapper<UnicodeString>> &iterable) {
   const auto size = iterable.size();
-  values_ = std::vector<_UTextPtr>(size);
-  sources_ = std::vector<UnicodeString>(iterable.begin(), iterable.end());
+  values_.reserve(size);
+  sources_.assign(iterable.begin(), iterable.end());
   ErrorCode error_code;
   for (size_t i = 0; i < size; ++i) {
     error_code.reset();
-    values_[i] = utext_openUnicodeString(nullptr, &sources_[i], error_code);
+    auto ut = utext_openUnicodeString(nullptr, &sources_[i].get(), error_code);
     if (error_code.isFailure()) {
-      throw ICUError(error_code);
+      throw icupy::ICUError(error_code);
     }
+    values_.push_back(ut);
   }
 }
 
 _UTextVector::~_UTextVector() { clear(); }
 
+void _UTextVector::append(UnicodeString &src) {
+  ErrorCode error_code;
+  auto ut = utext_openUnicodeString(nullptr, &src, error_code);
+  if (error_code.isFailure()) {
+    throw icupy::ICUError(error_code);
+  }
+  append(ut, src);
+}
+
+void _UTextVector::append(UText *ut, UnicodeString &src) {
+  values_.push_back(ut);
+  sources_.push_back(src);
+}
+
 void _UTextVector::clear() {
   for (size_t i = 0; i < values_.size(); ++i) {
     utext_close(values_[i]);
@@ -54,6 +62,42 @@ void _UTextVector::clear() {
   sources_.clear();
 }
 
+void _UTextVector::extend(const std::list<std::reference_wrapper<UnicodeString>> &iterable) {
+  for (auto &src : iterable) {
+    append(src);
+  }
+}
+
+void _UTextVector::insert(int32_t index, UnicodeString &src) {
+  const auto size = static_cast<int32_t>(values_.size());
+  if (index < 0) {
+    index += size;
+  }
+  if (index < 0 || index >= size) {
+    throw py::index_error("list index out of range: " + std::to_string(index));
+  }
+  ErrorCode error_code;
+  auto ut = utext_openUnicodeString(nullptr, &src, error_code);
+  if (error_code.isFailure()) {
+    throw icupy::ICUError(error_code);
+  }
+  values_.insert(values_.cbegin() + index, ut);
+  sources_.insert(sources_.cbegin() + index, src);
+}
+
+void _UTextVector::remove(int32_t index) {
+  const auto size = static_cast<int32_t>(values_.size());
+  if (index < 0) {
+    index += size;
+  }
+  if (index < 0 || index >= size) {
+    throw py::index_error("list index out of range: " + std::to_string(index));
+  }
+  utext_close(values_[index]);
+  values_.erase(values_.cbegin() + index);
+  sources_.erase(sources_.cbegin() + index);
+}
+
 void init_utext(py::module &m) {
   //
   // _UTextPtr
@@ -93,29 +137,65 @@ void init_utext(py::module &m) {
   //
   py::class_<_UTextVector> utv(m, "UTextVector");
 
-  utv.def(py::init<size_t>(), py::arg("n")).def(py::init<std::list<UnicodeString>>(), py::arg("iterable"));
+  utv.def(py::init<>())
+      .def(py::init<std::list<std::reference_wrapper<UnicodeString>>>(), py::keep_alive<1, 2>(), py::arg("iterable"));
 
   utv.def("__del__", &_UTextVector::clear);
 
+  utv.def("__delitem__", &_UTextVector::remove, py::arg("index"))
+      .def(
+          "__delitem__",
+          [](_UTextVector &self, const py::slice &index) {
+            size_t start = 0, stop = 0, step = 0, slice_length = 0;
+            if (!index.compute(self.size(), &start, &stop, &step, &slice_length)) {
+              throw py::error_already_set();
+            }
+            for (size_t n = 0; n < slice_length; ++n) {
+              self.remove(static_cast<int32_t>(start + (slice_length - n - 1) * step));
+            }
+          },
+          py::arg("index"));
+
   utv.def(
       "__getitem__",
-      [](const _UTextVector &self, size_t index) {
+      [](_UTextVector &self, int32_t index) -> _UTextPtr & {
+        const auto size = static_cast<int32_t>(self.size());
         if (index < 0) {
-          index += self.size();
+          index += size;
         }
-        if (index < 0 || index >= self.size()) {
-          throw py::index_error(std::to_string(index));
+        if (index < 0 || index >= size) {
+          throw py::index_error("list index out of range: " + std::to_string(index));
         }
         return self[index];
       },
-      py::arg("index"));
+      py::return_value_policy::reference_internal, py::arg("index"));
+
+  utv.def(
+      "__iadd__",
+      [](_UTextVector &self, const std::list<std::reference_wrapper<icu::UnicodeString>> &iterable) -> _UTextVector & {
+        self.extend(iterable);
+        return self;
+      },
+      py::keep_alive<1, 2>(), py::arg("iterable"));
 
   utv.def(
       "__iter__", [](const _UTextVector &self) { return py::make_iterator(self.begin(), self.end()); },
       py::keep_alive<0, 1>());
 
+  utv.def(
+      "__reversed__", [](const _UTextVector & /*self*/) { return py::none(); },
+      "``UTextVector`` does not support reverse iterator and always returns ``None``.");
+
   utv.def("__len__", &_UTextVector::size);
 
+  utv.def("append", py::overload_cast<UnicodeString &>(&_UTextVector::append), py::keep_alive<1, 2>(), py::arg("src"));
+
+  utv.def("clear", &_UTextVector::clear);
+
+  utv.def("extend", &_UTextVector::extend, py::keep_alive<1, 2>(), py::arg("iterable"));
+
+  utv.def("insert", &_UTextVector::insert, py::keep_alive<1, 3>(), py::arg("index"), py::arg("src"));
+
   //
   // Functions
   //
@@ -129,7 +209,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto p = utext_clone(dest.value_or(nullptr), src, deep, read_only, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p, src.get_source());
       },
@@ -153,7 +233,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         utext_copy(ut, native_start, native_limit, dest_index, move, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
       },
       py::arg("ut"), py::arg("native_start"), py::arg("native_limit"), py::arg("dest_index"), py::arg("move"));
@@ -173,7 +253,7 @@ void init_utext(py::module &m) {
         error_code.reset();
         utext_extract(ut, native_start, native_limit, result.data(), dest_capacity, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -217,7 +297,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto p = utext_openCharacterIterator(ut.value_or(nullptr), ci, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p);
       },
@@ -229,7 +309,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto p = utext_openConstUnicodeString(ut.value_or(nullptr), s, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p);
       },
@@ -241,7 +321,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto p = utext_openReplaceable(ut.value_or(nullptr), rep, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p);
       },
@@ -254,7 +334,7 @@ void init_utext(py::module &m) {
         auto text = std::make_shared<std::u16string>(s, s && length == -1 ? u_strlen(s) : std::max(int64_t{0}, length));
         auto p = utext_openUChars(ut.value_or(nullptr), text->data(), length, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p, text);
       },
@@ -266,7 +346,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto p = utext_openUnicodeString(ut.value_or(nullptr), s, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p);
       },
@@ -279,7 +359,7 @@ void init_utext(py::module &m) {
         auto text = std::make_shared<std::string>(s, s && length == -1 ? std::strlen(s) : std::max(int64_t{0}, length));
         auto p = utext_openUTF8(ut.value_or(nullptr), text->data(), length, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p, text);
       },
@@ -300,7 +380,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto result = utext_replace(ut, native_start, native_limit, replacement_text, replacement_length, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -319,7 +399,7 @@ void init_utext(py::module &m) {
         ErrorCode error_code;
         auto p = utext_setup(ut.value_or(nullptr), extra_space, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p);
       },
