@@ -456,15 +456,27 @@ def test_hash_code():
     assert bi1.hash_code() != bi2.hash_code()
     assert bi2.hash_code() == bi3.hash_code()
 
+    assert hash(bi1) == bi1.hash_code()
+    assert hash(bi2) == bi2.hash_code()
+    assert hash(bi3) == bi3.hash_code()
+
     src = UnicodeString("foo bar baz.")
     bi1.set_text(src)
     assert bi1.hash_code() != bi2.hash_code()
     assert bi2.hash_code() == bi3.hash_code()
 
+    assert hash(bi1) == bi1.hash_code()
+    assert hash(bi2) == bi2.hash_code()
+    assert hash(bi3) == bi3.hash_code()
+
     bi1.next()
     assert bi1.hash_code() != bi2.hash_code()
     assert bi2.hash_code() == bi3.hash_code()
 
+    assert hash(bi1) == bi1.hash_code()
+    assert hash(bi2) == bi2.hash_code()
+    assert hash(bi3) == bi3.hash_code()
+
 
 def test_is_boundary():
     bi = BreakIterator.create_word_instance(Locale.get_us())
@@ -634,7 +646,7 @@ def test_rule_based_break_iterator():
     #       UErrorCode &status
     # )
     binary_rules = bi3.get_binary_rules()
-    assert isinstance(binary_rules, list)
+    assert isinstance(binary_rules, bytes)
     assert len(binary_rules) > 0
     bi4 = RuleBasedBreakIterator(binary_rules, len(binary_rules))
     bi4.set_text(src)
