@@ -675,17 +675,80 @@ def test_extract_between():
     #       char16_t *dst,
     #       int32_t dstStart = 0
     # )
+    dest = test1.extract_between(0, 1)
+    assert isinstance(dest, str)
+    assert dest == "a"
+
+    dest = test1.extract_between(0, 3)
+    assert isinstance(dest, str)
+    assert dest == "a\U0001F338"  # "a\uD83C\uDF38" → "a\U0001F338"
+
+    dest = test1.extract_between(0, 4)
+    assert isinstance(dest, str)
+    assert dest == "a\U0001F338b"  # "a\uD83C\uDF38b" → "a\U0001F338b"
+
+    dest = test1.extract_between(0, 5)
+    assert isinstance(dest, str)
+    assert (
+        dest == "a\U0001F338b\x00"
+    )  # "a\uD83C\uDF38b\x00" → "a\U0001F338b\x00"
+
+    dest = test1.extract_between(0, 6)
+    assert isinstance(dest, str)
+    assert (
+        dest == "a\U0001F338b\x00c"
+    )  # "a\uD83C\uDF38b\x00c" → "a\U0001F338b\x00c"
+
+    dest = test1.extract_between(0, 1000)
+    assert isinstance(dest, str)
+    assert (
+        dest == "a\U0001F338b\x00c"
+    )  # "a\uD83C\uDF38b\x00c" → "a\U0001F338b\x00c"
+
+    dest = test1.extract_between(3, 3)
+    assert isinstance(dest, str)
+    assert len(dest) == 0
+
+    dest = test1.extract_between(3, 4)
+    assert isinstance(dest, str)
+    assert dest == "b"
+
+    dest = test1.extract_between(3, 5)
+    assert isinstance(dest, str)
+    assert dest == "b\x00"
+
     dest = test1.extract_between(3, 6)
     assert isinstance(dest, str)
     assert dest == "b\x00c"
 
-    dest = test1.extract_between(3, 5)
+    dest = test1.extract_between(4, 6)
     assert isinstance(dest, str)
-    assert dest == "b"
+    assert dest == "\x00c"
+
+    dest = test1.extract_between(5, 6)
+    assert isinstance(dest, str)
+    assert dest == "c"
+
+    dest = test1.extract_between(6, 7)
+    assert isinstance(dest, str)
+    assert len(dest) == 0
 
     dest = test2.extract_between(3, 6)
+    assert isinstance(dest, str)
+    assert len(dest) == 0  # test2 is not valid
+
+    dest = test1.extract_between(1, 0)
+    assert isinstance(dest, str)
     assert len(dest) == 0
 
+    dest = test1.extract_between(-2, -1)
+    assert isinstance(dest, str)
+    assert len(dest) == 0
+
+    dest = test1.extract_between(-2, 1)
+    assert isinstance(dest, str)
+    assert dest == "a"
+
     # [2]
     # void icu::UnicodeString::extractBetween(
     #       int32_t start,
@@ -903,6 +966,8 @@ def test_get_buffer():
     # [1]
     # const char16_t *icu::UnicodeString::getBuffer()
     p = test1.get_buffer()
+
+    # _ConstChar16Ptr.__getitem__(index: int) -> int
     assert p[0] == 0x61
     assert p[1] == 0x62
     assert p[2] == 0x63
@@ -910,8 +975,31 @@ def test_get_buffer():
     assert p[4] == 0x20
     assert p[5] == 0xDF38
 
+    _ = p[test1.get_capacity() - 1]
+    with pytest.raises(IndexError):
+        _ = p[test1.get_capacity()]
+
+    assert p[-1] == p[test1.get_capacity() - 1]
+    assert p[-test1.get_capacity()] == p[0]
+    with pytest.raises(IndexError):
+        _ = p[-test1.get_capacity() - 1]
+
+    assert list(p)[: test1.length()] == [
+        0x61,
+        0x62,
+        0x63,
+        0xD83C,
+        0x20,
+        0xDF38,
+    ]
+
+    # _ConstChar16Ptr.__len__()
+    assert len(p) == test1.get_capacity()
+
     # const char16_t *icu::UnicodeString::getTerminatedBuffer()
     p = test1.get_terminated_buffer()
+
+    # _ConstChar16Ptr.__getitem__(index: int) -> int
     assert p[0] == 0x61
     assert p[1] == 0x62
     assert p[2] == 0x63
@@ -920,6 +1008,28 @@ def test_get_buffer():
     assert p[5] == 0xDF38
     assert p[6] == 0
 
+    _ = p[test1.get_capacity() - 1]
+    with pytest.raises(IndexError):
+        _ = p[test1.get_capacity()]
+
+    assert p[-1] == p[test1.get_capacity() - 1]
+    assert p[-test1.get_capacity()] == p[0]
+    with pytest.raises(IndexError):
+        _ = p[-test1.get_capacity() - 1]
+
+    assert list(p)[: test1.length() + 1] == [
+        0x61,
+        0x62,
+        0x63,
+        0xD83C,
+        0x20,
+        0xDF38,
+        0,
+    ]
+
+    # _ConstChar16Ptr.__len__()
+    assert len(p) == test1.get_capacity()
+
     test1.set_to_bogus()
     assert test1.get_buffer() is None
     assert test1.get_terminated_buffer() is None
@@ -1333,6 +1443,7 @@ def test_operator():
     test3 = UnicodeString("foo bar")
 
     # UBool icu::UnicodeString::operator!=(const UnicodeString &text)
+    # UnicodeString.__ne__(other: UnicodeString|str) -> bool
     assert not (test1 != test2)
     assert test1 != test3
 
@@ -1340,6 +1451,7 @@ def test_operator():
     assert test1 != "foo bar"
 
     # UBool icu::UnicodeString::operator<(const UnicodeString &text)
+    # UnicodeString.__lt__(other: UnicodeString|str) -> bool
     assert not (test1 < test2)
     assert not (test1 < test3)
 
@@ -1347,6 +1459,7 @@ def test_operator():
     assert not (test1 < "foo bar")
 
     # UBool icu::UnicodeString::operator<=(const UnicodeString &text)
+    # UnicodeString.__le__(other: UnicodeString|str) -> bool
     assert test1 <= test2
     assert not (test1 <= test3)
 
@@ -1354,6 +1467,7 @@ def test_operator():
     assert not (test1 <= "foo bar")
 
     # UBool icu::UnicodeString::operator==(const UnicodeString &text)
+    # UnicodeString.__eq__(other: UnicodeString|str) -> bool
     assert test1 == test2
     assert not (test1 == test3)
 
@@ -1361,6 +1475,7 @@ def test_operator():
     assert not (test1 == "foo bar")
 
     # UBool icu::UnicodeString::operator>(const UnicodeString &text)
+    # UnicodeString.__gt__(other: UnicodeString|str) -> bool
     assert not (test1 > test2)
     assert test1 > test3
 
@@ -1368,6 +1483,7 @@ def test_operator():
     assert test1 > "foo bar"
 
     # UBool icu::UnicodeString::operator>=(const UnicodeString &text)
+    # UnicodeString.__ge__(other: UnicodeString|str) -> bool
     assert test1 >= test2
     assert test1 >= test3
 
@@ -1375,6 +1491,7 @@ def test_operator():
     assert test1 >= "foo bar"
 
     # char16_t icu::UnicodeString::operator[](int32_t offset)
+    # UnicodeString.__getitem__(index: int) -> str
     assert test1[0] == "f"
     assert test1[1] == "o"
     assert test1[2] == "o"
@@ -1395,6 +1512,8 @@ def test_operator():
         _ = test1[test1.length()]  # != U+ffff
     _ = test1[test1.length() - 1]
 
+    # UnicodeString.__getitem__(index: slice) -> UnicodeString
+    assert isinstance(test1[:], UnicodeString)
     assert test1[4:7] == "bar"
     assert test1[0:9:4] == "fbb"
     with pytest.raises(ValueError):  # ValueError: slice step cannot be zero
@@ -1403,31 +1522,80 @@ def test_operator():
     # UnicodeString &icu::UnicodeString::operator+=(
     #       const UnicodeString &srcText
     # )
+    # UnicodeString.__iadd__(other: UnicodeString)
+    object_id = id(test3)
     test3 += UnicodeString(" baz")
     assert isinstance(test3, UnicodeString)
     assert test3 == test1
+    assert id(test3) == object_id
 
+    # UnicodeString.__add__(other: UnicodeString)
     test4 = UnicodeString("foo bar") + UnicodeString(" baz")
     assert isinstance(test4, UnicodeString)
     assert test4 == test1
 
+    # UnicodeString.__iadd__(other: str)
     test5 = UnicodeString("foo bar")
+    object_id = id(test5)
     test5 += " baz"
     assert isinstance(test5, UnicodeString)
     assert test5 == test1
+    assert id(test5) == object_id
 
+    # UnicodeString.__add__(other: str)
     test6 = UnicodeString("foo bar") + " baz"
     assert isinstance(test6, UnicodeString)
     assert test6 == test1
 
     # UnicodeString &icu::UnicodeString::operator+=(UChar32 ch)
     # UnicodeString &icu::UnicodeString::operator+=(char16_t ch)
+    # UnicodeString.__iadd__(other: int)
     test7 = UnicodeString("a")
+    object_id = id(test7)
     test7 += 0x20402
     test7 += 0x62
     assert isinstance(test7, UnicodeString)
     expected = UnicodeString("a\\uD841\\uDC02b", -1, US_INV).unescape()
     assert test7 == expected
+    assert id(test7) == object_id
+
+
+def test_operator_setitem():
+    test1 = UnicodeString("abcd")
+
+    # UnicodeString.__setitem__(index: int, value: str|int)
+    test1[0] = "a"
+    test1[1] = 0xD83C
+    test1[2] = 0xDF08
+    test1[3] = "b"
+    assert str(test1) == "a\U0001f308b"
+
+    with pytest.raises(IndexError):
+        test1[4] = "c"  # index out of range
+
+    test1[-1] = "c"
+    assert str(test1) == "a\U0001f308c"
+
+    test1[-4] = "d"
+    assert str(test1) == "d\U0001f308c"
+
+    with pytest.raises(IndexError):
+        test1[-5] = "d"  # index out of range
+
+    with pytest.raises(ValueError):
+        test1[0] = "12"  # multi-character string
+
+    test1[0] = 0  # [0, 0xffff]
+    assert test1[0] == "\0"
+
+    with pytest.raises(TypeError):
+        test1[0] = -1  # [0, 0xffff]
+
+    test1[0] = 0xFFFF  # [0, 0xffff]
+    assert test1[0] == "\uffff"
+
+    with pytest.raises(TypeError):
+        test1[0] = 0x10000  # [0, 0xffff]
 
 
 def test_pad_leading():
@@ -2300,22 +2468,385 @@ def test_unicode_string_appendable():
 
 
 def test_unicode_string_vector():
-    t = UnicodeStringVector(3)
-    assert len(t) == 3
-    assert isinstance(t[0], UnicodeString)
-    assert isinstance(t[1], UnicodeString)
-    assert isinstance(t[2], UnicodeString)
+    # [1]
+    # UnicodeStringVector.__init__()
+    t1 = UnicodeStringVector()
+    assert len(t1) == 0
 
-    t[0].append("foo", -1)
-    t[1].append("bar", -1)
-    t[2].append("baz", -1)
-    assert t[0] == "foo"
-    assert t[1] == "bar"
-    assert t[2] == "baz"
+    # [2]
+    # UnicodeStringVector.__init__(n: int)
+    t2 = UnicodeStringVector(3)
+    assert len(t2) == 3
+    assert all(isinstance(x, UnicodeString) for x in t2)
+    assert len(t2[0]) == 0
+    assert len(t2[1]) == 0
+    assert len(t2[2]) == 0
 
-    s = [UnicodeString("foo"), UnicodeString("bar"), UnicodeString("baz")]
-    t = UnicodeStringVector(s)
-    assert len(t) == 3
-    assert t[0] == s[0]
-    assert t[1] == s[1]
-    assert t[2] == s[2]
+    # [3]
+    # UnicodeStringVector.__init__(other: UnicodeStringVector)
+    t2[0].set_to("foo")
+    t2[1].set_to("bar")
+    t2[2].set_to("baz")
+    t3 = UnicodeStringVector(t2)
+    assert len(t3) == 3
+    assert all(isinstance(x, UnicodeString) for x in t3)
+    assert t3[0] == "foo"
+    assert t3[1] == "bar"
+    assert t3[2] == "baz"
+
+    # [4]
+    # UnicodeStringVector.__init__(iterable: list[UnicodeString])
+    t4 = UnicodeStringVector(
+        [UnicodeString("foo"), UnicodeString("bar"), UnicodeString("baz")]
+    )
+    assert len(t4) == 3
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert t4[0] == "foo"
+    assert t4[1] == "bar"
+    assert t4[2] == "baz"
+
+    # [5]
+    # UnicodeStringVector.__init__(iterable: list[str])
+    t5 = UnicodeStringVector(["foo", "bar", "baz"])
+    assert len(t5) == 3
+    assert all(isinstance(x, UnicodeString) for x in t5)
+    assert t5[0] == "foo"
+    assert t5[1] == "bar"
+    assert t5[2] == "baz"
+
+
+def test_unicode_string_vector_api():
+    t1 = UnicodeStringVector(["foo"])
+
+    # UnicodeStringVector.append(item: UnicodeString|str)
+    t1.append(UnicodeString("bar"))
+    t1.append("baz")
+    assert len(t1) == 3
+    assert all(isinstance(x, UnicodeString) for x in t1)
+    assert list(map(str, t1)) == ["foo", "bar", "baz"]
+
+    # UnicodeStringVector.count(item: UnicodeString|str) -> int
+    t2 = UnicodeStringVector(t1)
+    t2.append("foo")
+    assert t2.count(UnicodeString("foo")) == 2
+    assert t2.count("foo") == 2
+    assert t2.count(UnicodeString("ba")) == 0
+    assert t2.count("ba") == 0
+
+    # [1]
+    # UnicodeStringVector.extend(iterable: list[UnicodeString])
+    t3 = UnicodeStringVector(t1)
+    t3.extend([UnicodeString("qux"), UnicodeString("quux")])
+    assert len(t3) == 5
+    assert all(isinstance(x, UnicodeString) for x in t3)
+    assert list(map(str, t3)) == ["foo", "bar", "baz", "qux", "quux"]
+
+    # [2]
+    # UnicodeStringVector.extend(iterable: list[str])
+    t3 = UnicodeStringVector(t1)
+    t3.extend(["qux", "quux"])
+    assert len(t3) == 5
+    assert all(isinstance(x, UnicodeString) for x in t3)
+    assert list(map(str, t3)) == ["foo", "bar", "baz", "qux", "quux"]
+
+    # UnicodeStringVector.insert(index: int, item: UnicodeString|str)
+    t4 = UnicodeStringVector(t1)
+    t4.insert(0, UnicodeString("0"))
+    assert len(t4) == 4
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert list(map(str, t4)) == ["0", "foo", "bar", "baz"]
+
+    t4.insert(-1, "-1")
+    assert len(t4) == 5
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert list(map(str, t4)) == ["0", "foo", "bar", "-1", "baz"]
+
+    with pytest.raises(IndexError):
+        t4.insert(5, "5")  # list index out of range
+
+    with pytest.raises(IndexError):
+        t4.insert(-6, "-6")  # list index out of range
+
+    # UnicodeStringVector.pop(index: int = -1) -> UnicodeString
+    t5 = UnicodeStringVector(["foo", "bar", "baz", "qux", "quux"])
+    item = t5.pop()
+    assert isinstance(item, UnicodeString)
+    assert item == "quux"
+    assert len(t5) == 4
+    assert list(map(str, t5)) == ["foo", "bar", "baz", "qux"]
+
+    item = t5.pop(0)
+    assert isinstance(item, UnicodeString)
+    assert item == "foo"
+    assert len(t5) == 3
+    assert list(map(str, t5)) == ["bar", "baz", "qux"]
+
+    item = t5.pop(-1)
+    assert isinstance(item, UnicodeString)
+    assert item == "qux"
+    assert len(t5) == 2
+    assert list(map(str, t5)) == ["bar", "baz"]
+
+    with pytest.raises(IndexError):
+        _ = t5.pop(2)  # list index out of range
+
+    with pytest.raises(IndexError):
+        _ = t5.pop(-3)  # list index out of range
+
+    # UnicodeStringVector.remove(item: UnicodeString|str)
+    t6 = UnicodeStringVector(["foo", "bar", "baz", "foo"])
+    t6.remove(UnicodeString("foo"))
+    assert len(t6) == 3
+    assert all(isinstance(x, UnicodeString) for x in t6)
+    assert list(map(str, t6)) == ["bar", "baz", "foo"]
+
+    t6.remove("baz")
+    assert len(t6) == 2
+    assert all(isinstance(x, UnicodeString) for x in t6)
+    assert list(map(str, t6)) == ["bar", "foo"]
+
+    with pytest.raises(ValueError):
+        t6.remove("baz")  # item not in list
+
+    # UnicodeStringVector.reverse()
+    t7 = UnicodeStringVector(t1)
+    assert t7.reverse() is None
+    assert len(t7) == 3
+    assert all(isinstance(x, UnicodeString) for x in t7)
+    assert list(map(str, t7)) == ["baz", "bar", "foo"]
+
+    # UnicodeStringVector.clear()
+    assert len(t1) > 0
+    t1.clear()
+    assert len(t1) == 0
+
+
+def test_unicode_string_vector_operators():
+    t1 = UnicodeStringVector(["foo", "bar", "baz"])
+    t2 = UnicodeStringVector(t1)
+    t3 = UnicodeStringVector(["foo", "bar", "baz", "qux"])
+
+    # UnicodeStringVector.__bool__() -> bool
+    assert bool(UnicodeStringVector(1))
+    assert not bool(UnicodeStringVector())
+
+    # UnicodeStringVector.__contains__(item: UnicodeString|str) -> bool
+    assert UnicodeString("bar") in t1
+    assert UnicodeString("ba") not in t1
+    assert "bar" in t1
+    assert "ba" not in t1
+
+    # UnicodeStringVector.__eq__(other: UnicodeStringVector) -> bool
+    assert t1 == t2
+    assert not (t1 == t3)
+
+    # UnicodeStringVector.__ne__(other: UnicodeStringVector) -> bool
+    assert not (t1 != t2)
+    assert t1 != t3
+
+    # [1]
+    # UnicodeStringVector.__getitem__(index: int) -> UnicodeString
+    item = t3[0]
+    assert isinstance(item, UnicodeString)
+    assert item == "foo"
+    item.set_to("FOO")
+    assert t3[0] == "FOO"
+
+    with pytest.raises(IndexError):
+        _ = t3[4]  # list index out of range
+
+    assert t3[-1] == t3[3]
+    assert t3[-2] == t3[2]
+    assert t3[-3] == t3[1]
+    assert t3[-4] == t3[0]
+
+    with pytest.raises(IndexError):
+        _ = t3[-5]  # list index out of range
+
+    # [2]
+    # UnicodeStringVector.__getitem__(index: slice) -> UnicodeStringVector
+    assert isinstance(t3[:], UnicodeStringVector)
+    t4 = t3[1::2]
+    assert len(t4) == 2
+    assert t4[0] == "bar"
+    assert t4[1] == "qux"
+
+    assert len(t3[0:0]) == 0
+
+    with pytest.raises(ValueError):
+        _ = t3[::0]  # slice step cannot be zero
+
+    # [1]
+    # UnicodeStringVector.__iadd__(item: UnicodeString|str) -> UnicodeStringVector
+    object_id4 = id(t4)
+    t4 += UnicodeString("a")
+    assert isinstance(t4, UnicodeStringVector)
+    assert id(t4) == object_id4
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert len(t4) == 3
+    assert list(map(str, t4)) == ["bar", "qux", "a"]
+
+    t4 += "ab"
+    assert isinstance(t4, UnicodeStringVector)
+    assert id(t4) == object_id4
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert len(t4) == 4
+    assert list(map(str, t4)) == ["bar", "qux", "a", "ab"]
+
+    # [2]
+    # UnicodeStringVector.__iadd__(iterable: list[UnicodeString]) -> UnicodeStringVector
+    t4 += [UnicodeString("abc"), UnicodeString("d")]
+    assert isinstance(t4, UnicodeStringVector)
+    assert id(t4) == object_id4
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert len(t4) == 6
+    assert list(map(str, t4)) == ["bar", "qux", "a", "ab", "abc", "d"]
+
+    t4 += UnicodeStringVector(["e", "fg"])
+    assert isinstance(t4, UnicodeStringVector)
+    assert id(t4) == object_id4
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert len(t4) == 8
+    assert list(map(str, t4)) == [
+        "bar",
+        "qux",
+        "a",
+        "ab",
+        "abc",
+        "d",
+        "e",
+        "fg",
+    ]
+
+    # [3]
+    # UnicodeStringVector.__iadd__(iterable: list[str]) -> UnicodeStringVector
+    t4 += ["h", "ijk"]
+    assert isinstance(t4, UnicodeStringVector)
+    assert id(t4) == object_id4
+    assert all(isinstance(x, UnicodeString) for x in t4)
+    assert len(t4) == 10
+    assert list(map(str, t4)) == [
+        "bar",
+        "qux",
+        "a",
+        "ab",
+        "abc",
+        "d",
+        "e",
+        "fg",
+        "h",
+        "ijk",
+    ]
+
+    # UnicodeStringVector.__iter__() -> Iterator[UnicodeString]
+    assert [str(x) for x in iter(t1)] == ["foo", "bar", "baz"]
+
+    # UnicodeStringVector.__repr__() -> str
+    assert repr(t1) == "UnicodeStringVector(['foo', 'bar', 'baz'])"
+
+    # UnicodeStringVector.__reversed__() -> UnicodeStringVector
+    t5 = UnicodeStringVector(t1)
+    t5r = reversed(t5)
+    assert isinstance(t5r, UnicodeStringVector)
+    assert len(t5) == len(t5r) == 3
+    assert all(isinstance(x, UnicodeString) for x in t5r)
+    assert list(map(str, t5)) == ["foo", "bar", "baz"]
+    assert list(map(str, t5r)) == ["baz", "bar", "foo"]
+
+    # [1]
+    # UnicodeStringVector.__setitem__(index: int, item: UnicodeString|str)
+    t6 = UnicodeStringVector(t3)
+    t6[3] = UnicodeString("QUX")
+    assert all(isinstance(x, UnicodeString) for x in t6)
+    assert list(map(str, t6)) == ["FOO", "bar", "baz", "QUX"]
+
+    t6[-1] = "qux"
+    assert list(map(str, t6)) == ["FOO", "bar", "baz", "qux"]
+
+    with pytest.raises(IndexError):
+        t6[4] = "quux"  # list index out of range
+
+    with pytest.raises(IndexError):
+        t6[-5] = "quux"  # list index out of range
+
+    # [2]
+    # UnicodeStringVector.__setitem__(index: slice, iterable: list[UnicodeString])
+    t6[::2] = [UnicodeString("Foo"), UnicodeString("Baz")]
+    assert list(map(str, t6)) == ["Foo", "bar", "Baz", "qux"]
+
+    with pytest.raises(ValueError):
+        t6[::0] = [UnicodeString("foo")]  # slice step cannot be zero
+
+    with pytest.raises(ValueError):
+        t6[:] = [
+            UnicodeString("foo")
+        ]  # attempt to assign sequence of size 1 to extended slice of size 4
+
+    # [3]
+    # UnicodeStringVector.__setitem__(index: slice, iterable: list[str])
+    t6[1::2] = ["BAR", "QUX"]
+    assert list(map(str, t6)) == ["Foo", "BAR", "Baz", "QUX"]
+
+    with pytest.raises(ValueError):
+        t6[::0] = ["foo"]  # slice step cannot be zero
+
+    with pytest.raises(ValueError):
+        t6[:] = [
+            "foo"
+        ]  # attempt to assign sequence of size 1 to extended slice of size 4
+
+    # [1]
+    # UnicodeStringVector.__delitem__(index: int)
+    t7 = UnicodeStringVector(list("0123456789"))
+    del t7[0]
+    assert list(map(str, t7)) == [
+        "1",
+        "2",
+        "3",
+        "4",
+        "5",
+        "6",
+        "7",
+        "8",
+        "9",
+    ]
+
+    del t7[-1]
+    assert list(map(str, t7)) == [
+        "1",
+        "2",
+        "3",
+        "4",
+        "5",
+        "6",
+        "7",
+        "8",
+    ]
+
+    with pytest.raises(IndexError):
+        del t7[8]  # list index out of range
+
+    with pytest.raises(IndexError):
+        del t7[-9]  # list index out of range
+
+    # [1]
+    # UnicodeStringVector.__delitem__(index: slice)
+    del t7[1:3]
+    assert list(map(str, t7)) == [
+        "1",
+        "4",
+        "5",
+        "6",
+        "7",
+        "8",
+    ]
+
+    del t7[1::2]
+    assert list(map(str, t7)) == [
+        "1",
+        "5",
+        "7",
+    ]
+
+    with pytest.raises(ValueError):
+        del t7[::0]  # slice step cannot be zero
